-- Copyright (C) 2000  Richie Bielak and others
-- Licensed under Eiffel Forum Freeware License, version 1;
-- (see forum.txt)
--
indexing

	description: "GDK_BIMAP - represents a GDK_BITMAP"

class GDK_BITMAP

inherit

	GDK_DRAWABLE
		rename
			drawable as bitmap
		export
			{ANY} bitmap
		redefine
			dispose
		end

	GDK_BITMAP_EXTERNALS
		undefine
			copy, is_equal
		end

	EXCEPTIONS
		undefine
			copy, is_equal
		end

creation

	make_from_pointer,
	make_from_file

feature -- creation

	make_from_pointer (a_bitmap: POINTER) is
		do
			bitmap := a_bitmap
			ref
		end

	make_from_file(f: STRING) is
			-- make from a pathname containing the bitmap; if this 
			-- cannot be read, an exception will be raised.
		local
			bfr: BINARY_FILE_READ
			s: STRING
			p: POINTER
		do
			p := Default_pointer
			create bfr.connect_to(f)
			if bfr.is_connected then
				from
					create s.make_empty
					bfr.read_byte
				until
					bfr.end_of_input
				loop
					s.extend(bfr.last_byte.to_character)
					bfr.read_byte
				end
				bfr.disconnect
				p := s.to_external
			else
				raise("Could not read bitmap file: " + f)
			end
			make_from_pointer(p)
		end

feature -- memory management

	ref is
		do
			bitmap := gdk_bitmap_ref (bitmap)
		end

	unref is
		do
			gdk_bitmap_unref (bitmap)
		end

	dispose is
		do
			precursor
			unref
		end
end
