
-- Copyright 1998 Richie Bielak and others
-- Licensed under Eiffel Forum Freeware License, version 1;
-- (see forum.txt)
--
indexing

	description: "GTK_PIXMAP - pixmap widget"
	version: "v 0.3.5 GTK+ 1.2.x"
	author: "Richie Bielak"
	cvs: "$Id: gtk_pixmap.e,v 1.15 2003/01/11 19:04:23 elphick Exp $"

class GTK_PIXMAP

-- An image defined by an array of characters at one byte per pixeL

inherit
	
	GTK_MISC

	GTK_RC
		undefine
			copy, is_equal
		end

	GTK_PIXMAP_EXTERNALS
		undefine
			copy, is_equal
		end

	EGTK_NON_PORTABLE
		undefine
			copy, is_equal
		end

	EXCEPTIONS
		undefine
			copy, is_equal
		end

creation

	make,
	make_from_xpm,
	make_from_xpm_and_mask,
	make_from_pointer

feature

	make (p: GDK_PIXMAP; m: POINTER) is
		require
			pixmap_not_void: p /= Void
		local
			mp: POINTER
		do
			pixmap := p
			mp := Default_pointer
			if m /= Default_pointer then
				create mask.make_from_pointer(m)
				mp := mask.bitmap
			end
			widget := gtk_pixmap_new (pixmap.pixmap, mp)
			register_widget
		end

	xpm_path: STRING

	make_from_xpm (new_parent: GTK_WIDGET; file_name: STRING) is
		require
			parent_not_void: new_parent /= Void
			file_name_valid: file_name /= Void and then file_name.count /= 0
		local
			p: GDK_PIXMAP
		do	
			xpm_path := rc_find_pixmap_in_path(file_name)
			if xpm_path /= Void then
				create p.make_from_xpm(new_parent.window, Void, xpm_path)
				make(p, Default_pointer)
				pixmap := p
				mask := Void
			else
				raise("Pixmap " + file_name + " not found")
			end
		end

	make_from_xpm_and_mask (new_parent: GTK_WIDGET; file_name, mask_name: STRING) is
			-- make a pixmap and mask from supplied filenames; the mask 
			-- file must be in the same directory as the pixmap
		require
			parent_not_void: new_parent /= Void
			file_name_valid: file_name /= Void and then file_name.count /= 0
			mask_name_valid: mask_name /= Void and then mask_name.count /= 0
			mask_name_relative: mask_name.index_of('/',1) = 0
		local
			p: GDK_PIXMAP
			s: STRING
		do	
			xpm_path := rc_find_pixmap_in_path(file_name)
			if xpm_path /= Void then
				create p.make_from_xpm(new_parent.window, Void, xpm_path)
				make(p, Default_pointer)
				pixmap := p
				s := clone(xpm_path)
				s.replace_substring(mask_name, s.reverse_index_of('/', s.count)+1, s.count)
				set_mask_from_file(s)
			else
				raise("Pixmap " + file_name + " not found")
			end
		end

	find_xpm(x: STRING) is
			-- locate the xpm file and set xpm_path to its path
		obsolete "Use rc files to set the pixmap search path"
		do
			-- default to current directory for now
			xpm_path := clone("./")
			xpm_path.append(x)
		end
	
	set_maps(p: GDK_PIXMAP; m: GDK_BITMAP) is
		-- Set the maps as directed
	 	require
			pixmap_supplied: p /= Void
		local
			mp: POINTER
		do
			if m = Void then
				mp := Default_pointer
			else
				mp := m.bitmap
			end
			mask := m
			gtk_pixmap_set(widget, p.pixmap, mp)
		end

	set_mask(m: GDK_BITMAP) is
		do
			set_maps(pixmap, m)
		end

	set_mask_from_file(filename: STRING) is
			-- Set the mask from the bitmap file whose name is supplied
		local
			b: GDK_BITMAP
		do
			create b.make_from_file(filename)
			set_mask(b)
		end

feature
	
	pixmap: GDK_PIXMAP

	mask: GDK_BITMAP

invariant

	pixmap_set: pixmap /= Void

end
